cmd

package
v0.0.0-...-dc0429e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 13, 2026 License: MIT Imports: 19 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	Up         = direction{1, 0}
	Down       = direction{1, 2}
	Left       = direction{0, 1}
	Right      = direction{2, 1}
	UpperRight = direction{2, 0}
	UpperLeft  = direction{0, 0}
	LowerRight = direction{2, 2}
	LowerLeft  = direction{0, 2}
	Middle     = direction{1, 1}
)
var Coords bool
var Verbose bool

Global flags

Functions

func Abs

func Abs(x int) int

func CeilDiv

func CeilDiv(x, y int) int

func DiagramFactory

func DiagramFactory(input string) (diagram.Diagram, error)

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

func Max

func Max(x, y int) int

func Min

func Min(x, y int) int

func RenderDiagram

func RenderDiagram(input string, config *diagram.Config) (string, error)

Types

type GraphDiagram

type GraphDiagram struct {
	// contains filtered or unexported fields
}

func (*GraphDiagram) Parse

func (gd *GraphDiagram) Parse(input string) error

func (*GraphDiagram) Render

func (gd *GraphDiagram) Render(config *diagram.Config) (string, error)

func (*GraphDiagram) Type

func (gd *GraphDiagram) Type() string

type SequenceDiagram

type SequenceDiagram struct {
	// contains filtered or unexported fields
}

func (*SequenceDiagram) Parse

func (sd *SequenceDiagram) Parse(input string) error

func (*SequenceDiagram) Render

func (sd *SequenceDiagram) Render(config *diagram.Config) (string, error)

func (*SequenceDiagram) Type

func (sd *SequenceDiagram) Type() string

Jump to